Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(936)

Unified Diff: pkg/analysis_server/lib/src/services/index/index_store.dart

Issue 1087483006: Rename two more classes to prepare for the public API (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analysis_server/lib/src/services/index/index_store.dart
diff --git a/pkg/analysis_server/lib/src/services/index/index_store.dart b/pkg/analysis_server/lib/src/services/index/index_store.dart
index 01e54e2a7b79078a6902a8e6c63388a741a8efa5..8dd931a1bd6a69439702ddf29a22e5c3111253a9 100644
--- a/pkg/analysis_server/lib/src/services/index/index_store.dart
+++ b/pkg/analysis_server/lib/src/services/index/index_store.dart
@@ -76,11 +76,11 @@ abstract class InternalIndexStore {
*
* [element] - the the [Element] that has the relationship with the locations
* to be returned.
* [relationship] - the [Relationship] between the given element and the
* locations to be returned
*/
- Future<List<Location>> getRelationships(
- Element element, Relationship relationship);
+ Future<List<LocationImpl>> getRelationships(
+ Element element, RelationshipImpl relationship);
/**
* Returns top-level [Element]s whose names satisfy to [nameFilter].
@@ -107,11 +107,11 @@ abstract class InternalIndexStore {
* would be a list containing both `location1` and `location2`.
*
* [element] - the [Element] that is related to the location.
* [relationship] - the [Relationship] between the element and the location.
* [location] the [Location] where relationship happens.
*/
void recordRelationship(
- Element element, Relationship relationship, Location location);
+ Element element, RelationshipImpl relationship, LocationImpl location);
/**
* Records the declaration of the given top-level [element].
@@ -76,11 +76,11 @@ abstract class InternalIndexStore {
* [element] - the the [Element] that has the relationship with the locations
* to be returned.
- * [relationship] - the [Relationship] between the given element and the
+ * [relationship] - the [RelationshipImpl] between the given element and the
* locations to be returned
*/
@@ -107,11 +107,11 @@ abstract class InternalIndexStore {
*
* [element] - the [Element] that is related to the location.
- * [relationship] - the [Relationship] between the element and the location.
- * [location] the [Location] where relationship happens.
+ * [relationship] - the [RelationshipImpl] between the element and the location.
+ * [location] the [LocationImpl] where relationship happens.
*/
void recordRelationship(

Powered by Google App Engine
This is Rietveld 408576698